@@ -16,6 +16,9 @@
  * dmeventd - dm event daemon to monitor active mapped devices
  */
 
+#define _GNU_SOURCE
+#define _FILE_OFFSET_BITS 64
+
 #include "libdevmapper.h"
 #include "libdevmapper-event.h"
 #include "list.h"
@@ -318,7 +321,7 @@ static int device_exists(char *device)
 	struct stat st_buf;
 	char path2[PATH_MAX];
 
-	if (!device)
+	if (!device || !*device)
 		return 0;
 
 	if (device[0] == '/') /* absolute path */
@@ -718,8 +721,11 @@ static struct dso_data *load_dso(struct message_data *data)
 	void *dl;
 	struct dso_data *ret = NULL;
 
+	log_very_verbose("Opening shared library %s", data->dso_name);
+
 	if (!(dl = dlopen(data->dso_name, RTLD_NOW))){
-		log_error("%s\n", dlerror());
+		log_error("dmeventd %s dlopen failed: %s", data->dso_name,
+			  dlerror());
 		return NULL;
 	}
 
